/* LAYOUT */

body {
  padding-top: 70px;
  padding-bottom: 20px;
}

hr {
  border-color: black;
}

.tab-row {
  margin-bottom: 10px;
}

/* BUTTONS */

.btn-actions {
  margin-bottom: 10px;
  margin-top: 20px;
}
